# -*-makefile-*-
# This makefile for MSVC has been tested with version 4.2 but should be ok with
# any 32-bit Microsoft compiler.
# 
# Author: Caleb Deupree <cdeupree@erinet.com>
# Modified by: Jon Berry <berryj@numen.elon.edu>
#

CC = cl -nologo
LINK = link -nologo -subsystem:windows
LIB32    = lib -nologo
RC   = rc

################################################
## These need to be set
################################################
LIBPATH = f:/WINAPPS/devstudio/vc
LIB = f:/WINAPPS/devstudio/vc/lib
STKLIBPATH = C:/STk/Lib
################################################

    
DEFINES = -DWIN32 -D_X86_ -DMSC_VER -DSTk_CODE -DSTK_VERSION=\"3.1\" \
-DMACHINE=\"MS_Win32\" -DUSE_TK -DUSE_HASH \
	-DUSE_STKLOS -DUSE_HTML -DUSE_REGEXP -DREDO_KEYSYM_LOOKUP -DNEED_MATHERR -DUSE_SOCKET
INCLUDES = -I/STk/include -I/STk/include/Tk/generic \
           -I/STk/include/Tk/win -I/STk/include/Tk/xlib \
           -I/STk/include/Tk/bitmaps -I../include

STDCMTLIB = $(LIBPATH)/lib/libcmt.lib
#STDCLIB = $(LIBPATH)/lib/libc.lib
STDCLIB = $(LIBPATH)/lib/libcd.lib
OLDNAMES = $(LIBPATH)/lib/oldnames.lib
KERNEL32 = $(LIBPATH)/lib/kernel32.lib
USER32 = $(LIBPATH)/lib/user32.lib
GDI32 = $(LIBPATH)/lib/gdi32.lib
COMDLG32 = $(LIBPATH)/lib/comdlg32.lib
WINSPOOL = $(LIBPATH)/lib/winspool.lib
ADVAPI32 = $(LIBPATH)/lib/advapi32.lib
SHELL32 = $(LIBPATH)/lib/shell32.lib
UUID = $(LIBPATH)/lib/uuid.lib
VERLIB = $(LIBPATH)/lib/version.lib
WSOCK32 = $(LIBPATH)/lib/wsock32.lib

SYSLIBS = $(USER32) $(GDI32) $(COMDLG32) $(WINSPOOL) $(ADVAPI32) $(SHELL32) $(UUID) $(VERLIB) \
        $(WSOCK32) $(STDCLIB)

STKLIB = $(STKLIBPATH)/stk.lib
TCLLIB = $(STKLIBPATH)/tcl.lib
TKLIB  = $(STKLIBPATH)/tkgen.lib
TKWINLIB=$(STKLIBPATH)/tkwin.lib
TKXLIB = $(STKLIBPATH)/tkxlib.lib

STKLIBS = $(STKLIB) $(TKXLIB) $(TKWINLIB) $(TKLIB) $(TCLLIB)

#
# options for debug or release
!IF "$(CFG)" == ""
WRK = dbg
DEBUGFLAGS = -Zi -W3 -Od -D_DEBUG
DEBUGLINKFLAGS = -nodefaultlib:libc -debug -pdb:$(WRK)/Link.pdb

!ELSEIF "$(CFG)" == "rel"
WRK = rel
DEBUGFLAGS = -W3 -Ot
DEBUGLINKFLAGS = 

!ENDIF

# had to add -GX because xstring uses the exception handler - JWB

# had to add -DANSIPROT because nauty defines this if __STDC__ is 
# defined (which should be the case).  VC++ *does not* define __STDC__
# by default while compiling a .cpp!	- JWB

# parser.cpp (produced by bison) needs MSDOS defined - JWB

# compiler runs out of heap space.  expand with -Zm    - JWB

CFLAGS = -GX -DANSIPROT -DSTK_GUI -DMSDOS -Zm200 $(DEBUGFLAGS) $(DEFINES) \
         $(INCLUDES) $(MULTITHREAD) -c
LINK_FLAGS = $(DEBUGLINKFLAGS) -MACHINE:I386 -INCREMENTAL:YES
LIB_FLAGS = /machine:x86
#
# Dependency List
#
Dep_Link = \
   Link.exe

Link : $(WRK) $(Dep_Link)

$(WRK):
	mkdir $(WRK)

clean:
	rm -rf dbg rel
	mkdir dbg rel
	rm -f *.exe *.lib *~ \#* 


Link.res :  Link.rc
  $(RC) /fo$@ Link.rc

Dep_Linkgraphlib= \
$(WRK)/AdjacencyMatrix.obj \
$(WRK)/BinGraph.obj\
$(WRK)/Buckets.obj\
$(WRK)/DBinGraph.obj\
$(WRK)/DHyperGraph.obj\
$(WRK)/Edge.obj\
$(WRK)/Graph.obj\
$(WRK)/graphTemplate.obj\
$(WRK)/GraphObject.obj\
$(WRK)/HyperGraph.obj\
$(WRK)/IncidenceMatrix.obj\
$(WRK)/LoadDimacsGraph.obj\
$(WRK)/SaveDimacsGraph.obj\
$(WRK)/UBinGraph.obj\
$(WRK)/UHyperGraph.obj\
$(WRK)/Vertex.obj\
$(WRK)/attrMethods.obj\
$(WRK)/parseGraph.obj \
$(WRK)/nauty.obj \
$(WRK)/nautil.obj \
$(WRK)/GraphBuild.obj\
$(WRK)/parser.obj \
$(WRK)/scanner.obj \
$(WRK)/_z_Array_AttributeBasep_Template.obj \
$(WRK)/_z_Array_Edgep_Template.obj \
$(WRK)/_z_Array_Graphp_Template.obj \
$(WRK)/_z_Array_VertexInfop_Template.obj \
$(WRK)/_z_Array_Vertexp_Template.obj \
$(WRK)/_z_Attribute_ContainerNodep_Template.obj \
$(WRK)/_z_Attribute_DJSetp_Template.obj \
$(WRK)/_z_Attribute_Edgep_Template.obj \
$(WRK)/_z_Attribute_GraphObjectp_Template.obj \
$(WRK)/_z_Attribute_Graphp_Template.obj \
$(WRK)/_z_Attribute_Vertexp_Template.obj \
$(WRK)/_z_Attribute_char_Template.obj \
$(WRK)/_z_Attribute_charp_Template.obj \
$(WRK)/_z_Attribute_double_Template.obj \
$(WRK)/_z_Attribute_float_Template.obj \
$(WRK)/_z_Attribute_int_Template.obj \
$(WRK)/_z_Collection_AttributeBasep_Template.obj \
$(WRK)/_z_Collection_Edgep_Template.obj \
$(WRK)/_z_Collection_Graphp_Template.obj \
$(WRK)/_z_Collection_VertexInfop_Template.obj \
$(WRK)/_z_Collection_Vertexp_Template.obj \
$(WRK)/_z_Container_AttributeBasep_Template.obj \
$(WRK)/_z_Container_Edgep_Template.obj \
$(WRK)/_z_Container_Graphp_Template.obj \
$(WRK)/_z_Container_VertexInfop_Template.obj \
$(WRK)/_z_Container_Vertexp_Template.obj \
$(WRK)/_z_DList_AttributeBasep_Template.obj \
$(WRK)/_z_DList_Edgep_Template.obj \
$(WRK)/_z_DList_Graphp_Template.obj \
$(WRK)/_z_DList_VertexInfop_Template.obj \
$(WRK)/_z_DList_Vertexp_Template.obj \
$(WRK)/_z_ElementOps_AttributeBase_Template.obj \
$(WRK)/_z_ElementOps_AttributeBasep_Template.obj \
$(WRK)/_z_ElementOps_BinGraph_Template.obj \
$(WRK)/_z_ElementOps_BinGraphp_Template.obj \
$(WRK)/_z_ElementOps_DBinGraph_Template.obj \
$(WRK)/_z_ElementOps_DBinGraphp_Template.obj \
$(WRK)/_z_ElementOps_DHyperGraph_Template.obj \
$(WRK)/_z_ElementOps_DHyperGraphp_Template.obj \
$(WRK)/_z_ElementOps_Edge_Template.obj \
$(WRK)/_z_ElementOps_Edgep_Template.obj \
$(WRK)/_z_ElementOps_Graph_Template.obj \
$(WRK)/_z_ElementOps_Graphp_Template.obj \
$(WRK)/_z_ElementOps_HyperGraph_Template.obj \
$(WRK)/_z_ElementOps_HyperGraphp_Template.obj \
$(WRK)/_z_ElementOps_MBinGraph_Template.obj \
$(WRK)/_z_ElementOps_MBinGraphp_Template.obj \
$(WRK)/_z_ElementOps_MDBinGraph_Template.obj \
$(WRK)/_z_ElementOps_MDBinGraphp_Template.obj \
$(WRK)/_z_ElementOps_MDHyperGraph_Template.obj \
$(WRK)/_z_ElementOps_MDHyperGraphp_Template.obj \
$(WRK)/_z_ElementOps_MHyperGraph_Template.obj \
$(WRK)/_z_ElementOps_MHyperGraphp_Template.obj \
$(WRK)/_z_ElementOps_MUBinGraph_Template.obj \
$(WRK)/_z_ElementOps_MUBinGraphp_Template.obj \
$(WRK)/_z_ElementOps_MUHyperGraph_Template.obj \
$(WRK)/_z_ElementOps_MUHyperGraphp_Template.obj \
$(WRK)/_z_ElementOps_UBinGraph_Template.obj \
$(WRK)/_z_ElementOps_UBinGraphp_Template.obj \
$(WRK)/_z_ElementOps_UHyperGraph_Template.obj \
$(WRK)/_z_ElementOps_UHyperGraphp_Template.obj \
$(WRK)/_z_ElementOps_VertexInfop_Template.obj \
$(WRK)/_z_ElementOps_Vertex_Template.obj \
$(WRK)/_z_ElementOps_Vertexp_Template.obj \
$(WRK)/_z_Iterator_AttributeBasep_Template.obj \
$(WRK)/_z_Iterator_Edgep_Template.obj \
$(WRK)/_z_Iterator_Graphp_Template.obj \
$(WRK)/_z_Iterator_VertexInfop_Template.obj \
$(WRK)/_z_Iterator_Vertexp_Template.obj \
$(WRK)/_z_List_AttributeBasep_Template.obj \
$(WRK)/_z_List_Edgep_Template.obj \
$(WRK)/_z_List_Graphp_Template.obj \
$(WRK)/_z_List_VertexInfop_Template.obj \
$(WRK)/_z_List_Vertexp_Template.obj \
$(WRK)/_z_MSet_AttributeBasep_Template.obj \
$(WRK)/_z_MSet_Edgep_Template.obj \
$(WRK)/_z_MSet_Graphp_Template.obj \
$(WRK)/_z_MSet_VertexInfop_Template.obj \
$(WRK)/_z_MSet_Vertexp_Template.obj \
$(WRK)/_z_Sequence_AttributeBasep_Template.obj \
$(WRK)/_z_Sequence_Edgep_Template.obj \
$(WRK)/_z_Sequence_Graphp_Template.obj \
$(WRK)/_z_Sequence_VertexInfop_Template.obj \
$(WRK)/_z_Sequence_Vertexp_Template.obj \
$(WRK)/_z_SetFuncs_AttributeBasep_Template.obj \
$(WRK)/_z_SetFuncs_Edgep_Template.obj \
$(WRK)/_z_SetFuncs_Graphp_Template.obj \
$(WRK)/_z_SetFuncs_Vertexp_Template.obj \
$(WRK)/_z_Set_AttributeBasep_Template.obj \
$(WRK)/_z_Set_Edgep_Template.obj \
$(WRK)/_z_Set_Graphp_Template.obj \
$(WRK)/_z_Set_VertexInfop_Template.obj \
$(WRK)/_z_Set_Vertexp_Template.obj \
$(WRK)/_z_SimpleContainer_AttributeBasep_Template.obj \
$(WRK)/_z_SimpleContainer_Edgep_Template.obj \
$(WRK)/_z_SimpleContainer_Graphp_Template.obj \
$(WRK)/_z_SimpleContainer_VertexInfop_Template.obj \
$(WRK)/_z_SimpleContainer_Vertexp_Template.obj \
$(WRK)/_z_SortedArray_AttributeBasep_Template.obj \
$(WRK)/_z_SortedArray_Edgep_Template.obj \
$(WRK)/_z_SortedArray_Graphp_Template.obj \
$(WRK)/_z_SortedArray_VertexInfop_Template.obj \
$(WRK)/_z_SortedArray_Vertexp_Template.obj \
$(WRK)/_z_SortedList_AttributeBasep_Template.obj \
$(WRK)/_z_SortedList_Edgep_Template.obj \
$(WRK)/_z_SortedList_Graphp_Template.obj \
$(WRK)/_z_SortedList_VertexInfop_Template.obj \
$(WRK)/_z_SortedList_Vertexp_Template.obj \
$(WRK)/_z_SubSet_AttributeBasep_Template.obj \
$(WRK)/_z_SubSet_Edgep_Template.obj \
$(WRK)/_z_SubSet_Graphp_Template.obj \
$(WRK)/_z_SubSet_Vertexp_Template.obj \
$(WRK)/_zz_Array_DList_VertexInfop__Template.obj \
$(WRK)/_zz_Array_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Array_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Array_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Array_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Array_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Array_Set_Edgep__Template.obj \
$(WRK)/_zz_Array_Set_Graphp__Template.obj \
$(WRK)/_zz_Array_Set_Vertexp__Template.obj \
$(WRK)/_zz_Array_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_Array_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Array_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Array_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Array_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_Attribute_DList_Vertexp_p_Template.obj \
$(WRK)/_zz_Attribute_List_Vertexp_p_Template.obj \
$(WRK)/_zz_Collection_DList_VertexInfop__Template.obj \
$(WRK)/_zz_Collection_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Collection_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Collection_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Collection_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Collection_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Collection_Set_Edgep__Template.obj \
$(WRK)/_zz_Collection_Set_Graphp__Template.obj \
$(WRK)/_zz_Collection_Set_Vertexp__Template.obj \
$(WRK)/_zz_Collection_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_Collection_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Collection_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Collection_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Collection_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_Container_DList_VertexInfop__Template.obj \
$(WRK)/_zz_Container_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Container_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Container_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Container_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Container_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Container_Set_Edgep__Template.obj \
$(WRK)/_zz_Container_Set_Graphp__Template.obj \
$(WRK)/_zz_Container_Set_Vertexp__Template.obj \
$(WRK)/_zz_Container_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_Container_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Container_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Container_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Container_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_DList_DList_VertexInfop__Template.obj \
$(WRK)/_zz_DList_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_DList_Sequence_Edgep__Template.obj \
$(WRK)/_zz_DList_Sequence_Graphp__Template.obj \
$(WRK)/_zz_DList_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_DList_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_DList_Set_Edgep__Template.obj \
$(WRK)/_zz_DList_Set_Graphp__Template.obj \
$(WRK)/_zz_DList_Set_Vertexp__Template.obj \
$(WRK)/_zz_DList_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_DList_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_DList_SubSet_Edgep__Template.obj \
$(WRK)/_zz_DList_SubSet_Graphp__Template.obj \
$(WRK)/_zz_DList_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_Array_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_Array_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_Array_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_Array_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_Array_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_ContainerNodep__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_ContainerNodep_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_DJSetp__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_DJSetp_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_Edgep_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_GraphObjectp__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_GraphObjectp_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_Graphp_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_Vertexp_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_char__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_char_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_charp__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_charp_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_double__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_double_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_float__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_float_p_Template.obj \
$(WRK)/_zz_ElementOps_Attribute_int__Template.obj \
$(WRK)/_zz_ElementOps_Attribute_int_p_Template.obj \
$(WRK)/_zz_ElementOps_Collection_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_Collection_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_Collection_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_Collection_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_Collection_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_Container_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_Container_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_Container_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_Container_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_Container_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_DList_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_DList_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_DList_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_DList_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_DList_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_List_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_List_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_List_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_List_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_List_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_MSet_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_MSet_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_MSet_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_MSet_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_MSet_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_SetFuncs_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_SetFuncs_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_SetFuncs_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_SetFuncs_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_Set_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_Set_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_Set_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_Set_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_VertexInfop__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_Vertexp__Template.obj \
$(WRK)/_zz_ElementOps_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_ElementOps_SubSet_Edgep__Template.obj \
$(WRK)/_zz_ElementOps_SubSet_Graphp__Template.obj \
$(WRK)/_zz_ElementOps_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_Iterator_DList_VertexInfop__Template.obj \
$(WRK)/_zz_Iterator_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Iterator_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Iterator_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Iterator_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Iterator_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Iterator_Set_Edgep__Template.obj \
$(WRK)/_zz_Iterator_Set_Graphp__Template.obj \
$(WRK)/_zz_Iterator_Set_Vertexp__Template.obj \
$(WRK)/_zz_Iterator_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_Iterator_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Iterator_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Iterator_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Iterator_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_List_DList_VertexInfop__Template.obj \
$(WRK)/_zz_List_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_List_Sequence_Edgep__Template.obj \
$(WRK)/_zz_List_Sequence_Graphp__Template.obj \
$(WRK)/_zz_List_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_List_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_List_Set_Edgep__Template.obj \
$(WRK)/_zz_List_Set_Graphp__Template.obj \
$(WRK)/_zz_List_Set_Vertexp__Template.obj \
$(WRK)/_zz_List_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_List_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_List_SubSet_Edgep__Template.obj \
$(WRK)/_zz_List_SubSet_Graphp__Template.obj \
$(WRK)/_zz_List_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_MSetBase_AttributeBasep_List_AttributeBasep__Template.obj \
$(WRK)/_zz_MSetBase_AttributeBasep_SortedList_AttributeBasep__Template.obj \
$(WRK)/_zz_MSetBase_Edgep_List_Edgep__Template.obj \
$(WRK)/_zz_MSetBase_Edgep_SortedList_Edgep__Template.obj \
$(WRK)/_zz_MSetBase_Graphp_List_Graphp__Template.obj \
$(WRK)/_zz_MSetBase_Graphp_SortedList_Graphp__Template.obj \
$(WRK)/_zz_MSetBase_VertexInfop_List_VertexInfop__Template.obj \
$(WRK)/_zz_MSetBase_VertexInfop_SortedList_VertexInfop__Template.obj \
$(WRK)/_zz_MSetBase_Vertexp_List_Vertexp__Template.obj \
$(WRK)/_zz_MSetBase_Vertexp_SortedList_Vertexp__Template.obj \
$(WRK)/_zz_MSet_DList_VertexInfop__Template.obj \
$(WRK)/_zz_MSet_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_MSet_Sequence_Edgep__Template.obj \
$(WRK)/_zz_MSet_Sequence_Graphp__Template.obj \
$(WRK)/_zz_MSet_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_MSet_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_MSet_Set_Edgep__Template.obj \
$(WRK)/_zz_MSet_Set_Graphp__Template.obj \
$(WRK)/_zz_MSet_Set_Vertexp__Template.obj \
$(WRK)/_zz_MSet_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_MSet_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_MSet_SubSet_Edgep__Template.obj \
$(WRK)/_zz_MSet_SubSet_Graphp__Template.obj \
$(WRK)/_zz_MSet_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_SequenceBase_AttributeBasep_List_AttributeBasep__Template.obj \
$(WRK)/_zz_SequenceBase_Edgep_List_Edgep__Template.obj \
$(WRK)/_zz_SequenceBase_Graphp_List_Graphp__Template.obj \
$(WRK)/_zz_SequenceBase_VertexInfop_List_VertexInfop__Template.obj \
$(WRK)/_zz_SequenceBase_Vertexp_List_Vertexp__Template.obj \
$(WRK)/_zz_Sequence_DList_VertexInfop__Template.obj \
$(WRK)/_zz_Sequence_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Sequence_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Sequence_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Sequence_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Sequence_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Sequence_Set_Edgep__Template.obj \
$(WRK)/_zz_Sequence_Set_Graphp__Template.obj \
$(WRK)/_zz_Sequence_Set_Vertexp__Template.obj \
$(WRK)/_zz_Sequence_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_Sequence_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Sequence_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Sequence_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Sequence_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_SetBase_AttributeBasep_SortedList_AttributeBasep__Template.obj \
$(WRK)/_zz_SetBase_Edgep_SortedList_Edgep__Template.obj \
$(WRK)/_zz_SetBase_Graphp_SortedList_Graphp__Template.obj \
$(WRK)/_zz_SetBase_VertexInfop_SortedList_VertexInfop__Template.obj \
$(WRK)/_zz_SetBase_Vertexp_SortedList_Vertexp__Template.obj \
$(WRK)/_zz_Set_DList_VertexInfop__Template.obj \
$(WRK)/_zz_Set_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Set_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Set_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Set_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Set_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Set_Set_Edgep__Template.obj \
$(WRK)/_zz_Set_Set_Graphp__Template.obj \
$(WRK)/_zz_Set_Set_Vertexp__Template.obj \
$(WRK)/_zz_Set_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_Set_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Set_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Set_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Set_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_SimpleContainer_DList_VertexInfop__Template.obj \
$(WRK)/_zz_SimpleContainer_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_SimpleContainer_Sequence_Edgep__Template.obj \
$(WRK)/_zz_SimpleContainer_Sequence_Graphp__Template.obj \
$(WRK)/_zz_SimpleContainer_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_SimpleContainer_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_SimpleContainer_Set_Edgep__Template.obj \
$(WRK)/_zz_SimpleContainer_Set_Graphp__Template.obj \
$(WRK)/_zz_SimpleContainer_Set_Vertexp__Template.obj \
$(WRK)/_zz_SimpleContainer_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_SimpleContainer_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_SimpleContainer_SubSet_Edgep__Template.obj \
$(WRK)/_zz_SimpleContainer_SubSet_Graphp__Template.obj \
$(WRK)/_zz_SimpleContainer_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_SortedArray_DList_VertexInfop__Template.obj \
$(WRK)/_zz_SortedArray_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_SortedArray_Sequence_Edgep__Template.obj \
$(WRK)/_zz_SortedArray_Sequence_Graphp__Template.obj \
$(WRK)/_zz_SortedArray_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_SortedArray_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_SortedArray_Set_Edgep__Template.obj \
$(WRK)/_zz_SortedArray_Set_Graphp__Template.obj \
$(WRK)/_zz_SortedArray_Set_Vertexp__Template.obj \
$(WRK)/_zz_SortedArray_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_SortedArray_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_SortedArray_SubSet_Edgep__Template.obj \
$(WRK)/_zz_SortedArray_SubSet_Graphp__Template.obj \
$(WRK)/_zz_SortedArray_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_SortedList_DList_VertexInfop__Template.obj \
$(WRK)/_zz_SortedList_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_SortedList_Sequence_Edgep__Template.obj \
$(WRK)/_zz_SortedList_Sequence_Graphp__Template.obj \
$(WRK)/_zz_SortedList_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_SortedList_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_SortedList_Set_Edgep__Template.obj \
$(WRK)/_zz_SortedList_Set_Graphp__Template.obj \
$(WRK)/_zz_SortedList_Set_Vertexp__Template.obj \
$(WRK)/_zz_SortedList_Set_Vertexp_p_Template.obj \
$(WRK)/_zz_SortedList_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_SortedList_SubSet_Edgep__Template.obj \
$(WRK)/_zz_SortedList_SubSet_Graphp__Template.obj \
$(WRK)/_zz_SortedList_SubSet_Vertexp__Template.obj \
$(WRK)/_zzz_ElementOps_Array_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_Array_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Array_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Array_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Attribute_DList_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_Attribute_DList_Vertexp_p_p_Template.obj \
$(WRK)/_zzz_ElementOps_Attribute_List_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_Attribute_List_Vertexp_p_p_Template.obj \
$(WRK)/_zzz_ElementOps_Collection_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_Collection_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_Container_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Container_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Container_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_DList_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_DList_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_DList_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_List_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_List_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_List_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_List_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_List_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_List_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_List_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_List_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_List_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_List_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_List_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_List_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_List_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_List_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_MSet_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_Set_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_Set_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_Set_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_DList_VertexInfop___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Sequence_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Set_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Set_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Set_Vertexp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Set_Vertexp_p__Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_SubSet_Vertexp___Template.obj \
$(WRK)/_zzzz_MSetBase_DList_VertexInfop__List_DList_VertexInfop___Template.obj \
$(WRK)/_zzzz_MSetBase_DList_VertexInfop__SortedList_DList_VertexInfop___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_AttributeBasep__List_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_AttributeBasep__SortedList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_Edgep__List_Sequence_Edgep___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_Edgep__SortedList_Sequence_Edgep___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_Graphp__List_Sequence_Graphp___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_Graphp__SortedList_Sequence_Graphp___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_Vertexp__List_Sequence_Vertexp___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_Vertexp__SortedList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_AttributeBasep__List_Set_AttributeBasep___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_AttributeBasep__SortedList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Edgep__List_Set_Edgep___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Edgep__SortedList_Set_Edgep___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Graphp__List_Set_Graphp___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Graphp__SortedList_Set_Graphp___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Vertexp__List_Set_Vertexp___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Vertexp__SortedList_Set_Vertexp___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Vertexp_p_List_Set_Vertexp_p__Template.obj \
$(WRK)/_zzzz_MSetBase_Set_Vertexp_p_SortedList_Set_Vertexp_p__Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_AttributeBasep__List_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_AttributeBasep__SortedList_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_Edgep__List_SubSet_Edgep___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_Edgep__SortedList_SubSet_Edgep___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_Graphp__List_SubSet_Graphp___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_Graphp__SortedList_SubSet_Graphp___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_Vertexp__List_SubSet_Vertexp___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_Vertexp__SortedList_SubSet_Vertexp___Template.obj \
$(WRK)/_zzzz_SequenceBase_DList_VertexInfop__List_DList_VertexInfop___Template.obj \
$(WRK)/_zzzz_SequenceBase_Sequence_AttributeBasep__List_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzzz_SequenceBase_Sequence_Edgep__List_Sequence_Edgep___Template.obj \
$(WRK)/_zzzz_SequenceBase_Sequence_Graphp__List_Sequence_Graphp___Template.obj \
$(WRK)/_zzzz_SequenceBase_Sequence_Vertexp__List_Sequence_Vertexp___Template.obj \
$(WRK)/_zzzz_SequenceBase_Set_AttributeBasep__List_Set_AttributeBasep___Template.obj \
$(WRK)/_zzzz_SequenceBase_Set_Edgep__List_Set_Edgep___Template.obj \
$(WRK)/_zzzz_SequenceBase_Set_Graphp__List_Set_Graphp___Template.obj \
$(WRK)/_zzzz_SequenceBase_Set_Vertexp__List_Set_Vertexp___Template.obj \
$(WRK)/_zzzz_SequenceBase_Set_Vertexp_p_List_Set_Vertexp_p__Template.obj \
$(WRK)/_zzzz_SequenceBase_SubSet_AttributeBasep__List_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzzz_SequenceBase_SubSet_Edgep__List_SubSet_Edgep___Template.obj \
$(WRK)/_zzzz_SequenceBase_SubSet_Graphp__List_SubSet_Graphp___Template.obj \
$(WRK)/_zzzz_SequenceBase_SubSet_Vertexp__List_SubSet_Vertexp___Template.obj \
$(WRK)/_zzzz_SetBase_DList_VertexInfop__SortedList_DList_VertexInfop___Template.obj \
$(WRK)/_zzzz_SetBase_Sequence_AttributeBasep__SortedList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzzz_SetBase_Sequence_Edgep__SortedList_Sequence_Edgep___Template.obj \
$(WRK)/_zzzz_SetBase_Sequence_Graphp__SortedList_Sequence_Graphp___Template.obj \
$(WRK)/_zzzz_SetBase_Sequence_Vertexp__SortedList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzzz_SetBase_Set_AttributeBasep__SortedList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzzz_SetBase_Set_Edgep__SortedList_Set_Edgep___Template.obj \
$(WRK)/_zzzz_SetBase_Set_Graphp__SortedList_Set_Graphp___Template.obj \
$(WRK)/_zzzz_SetBase_Set_Vertexp__SortedList_Set_Vertexp___Template.obj \
$(WRK)/_zzzz_SetBase_Set_Vertexp_p_SortedList_Set_Vertexp_p__Template.obj \
$(WRK)/_zzzz_SetBase_SubSet_AttributeBasep__SortedList_SubSet_AttributeBasep___Template.obj \
$(WRK)/_zzzz_SetBase_SubSet_Edgep__SortedList_SubSet_Edgep___Template.obj \
$(WRK)/_zzzz_SetBase_SubSet_Graphp__SortedList_SubSet_Graphp___Template.obj \
$(WRK)/_zzzz_SetBase_SubSet_Vertexp__SortedList_SubSet_Vertexp___Template.obj 

Dep_Linkbasiclib = \
$(WRK)/DJSet.obj \
$(WRK)/Location.obj  \
$(WRK)/basicUtils.obj \
$(WRK)/Error.obj  \
$(WRK)/Permutation.obj  \
$(WRK)/count.obj \
$(WRK)/InitRand.obj  \
$(WRK)/Point.obj \
$(WRK)/LaplacianMatrix.obj   \
$(WRK)/basicTemplate.obj \
$(WRK)/_z_Array_char_Template.obj \
$(WRK)/_z_Array_charp_Template.obj \
$(WRK)/_z_Array_double_Template.obj \
$(WRK)/_z_Array_int_Template.obj \
$(WRK)/_z_Collection_char_Template.obj \
$(WRK)/_z_Collection_charp_Template.obj \
$(WRK)/_z_Collection_double_Template.obj \
$(WRK)/_z_Collection_int_Template.obj \
$(WRK)/_z_Container_char_Template.obj \
$(WRK)/_z_Container_charp_Template.obj \
$(WRK)/_z_Container_double_Template.obj \
$(WRK)/_z_Container_int_Template.obj \
$(WRK)/_z_DList_char_Template.obj \
$(WRK)/_z_DList_charp_Template.obj \
$(WRK)/_z_DList_double_Template.obj \
$(WRK)/_z_DList_int_Template.obj \
$(WRK)/_z_ElementOps_char_Template.obj \
$(WRK)/_z_ElementOps_double_Template.obj \
$(WRK)/_z_ElementOps_int_Template.obj \
$(WRK)/_z_Iterator_char_Template.obj \
$(WRK)/_z_Iterator_charp_Template.obj \
$(WRK)/_z_Iterator_double_Template.obj \
$(WRK)/_z_Iterator_int_Template.obj \
$(WRK)/_z_List_char_Template.obj \
$(WRK)/_z_List_charp_Template.obj \
$(WRK)/_z_List_double_Template.obj \
$(WRK)/_z_List_int_Template.obj \
$(WRK)/_z_MSet_char_Template.obj \
$(WRK)/_z_MSet_charp_Template.obj \
$(WRK)/_z_MSet_double_Template.obj \
$(WRK)/_z_MSet_int_Template.obj \
$(WRK)/_z_Sequence_char_Template.obj \
$(WRK)/_z_Sequence_charp_Template.obj \
$(WRK)/_z_Sequence_double_Template.obj \
$(WRK)/_z_Sequence_int_Template.obj \
$(WRK)/_z_SetFuncs_int_Template.obj \
$(WRK)/_z_Set_char_Template.obj \
$(WRK)/_z_Set_charp_Template.obj \
$(WRK)/_z_Set_double_Template.obj \
$(WRK)/_z_Set_int_Template.obj \
$(WRK)/_z_SimpleContainer_char_Template.obj \
$(WRK)/_z_SimpleContainer_charp_Template.obj \
$(WRK)/_z_SimpleContainer_double_Template.obj \
$(WRK)/_z_SimpleContainer_int_Template.obj \
$(WRK)/_z_SortedArray_char_Template.obj \
$(WRK)/_z_SortedArray_charp_Template.obj \
$(WRK)/_z_SortedArray_double_Template.obj \
$(WRK)/_z_SortedArray_int_Template.obj \
$(WRK)/_z_SortedList_char_Template.obj \
$(WRK)/_z_SortedList_charp_Template.obj \
$(WRK)/_z_SortedList_double_Template.obj \
$(WRK)/_z_SortedList_int_Template.obj \
$(WRK)/_z_SubSet_int_Template.obj \
$(WRK)/_zz_Array_List_int__Template.obj \
$(WRK)/_zz_Array_MSet_charp__Template.obj \
$(WRK)/_zz_Array_MSet_int__Template.obj \
$(WRK)/_zz_Array_Sequence_charp__Template.obj \
$(WRK)/_zz_Array_Sequence_int__Template.obj \
$(WRK)/_zz_Array_Set_charp__Template.obj \
$(WRK)/_zz_Array_Set_int__Template.obj \
$(WRK)/_zz_Array_SubSet_int__Template.obj \
$(WRK)/_zz_Collection_List_int__Template.obj \
$(WRK)/_zz_Collection_MSet_charp__Template.obj \
$(WRK)/_zz_Collection_MSet_int__Template.obj \
$(WRK)/_zz_Collection_Sequence_charp__Template.obj \
$(WRK)/_zz_Collection_Sequence_int__Template.obj \
$(WRK)/_zz_Collection_Set_charp__Template.obj \
$(WRK)/_zz_Collection_Set_int__Template.obj \
$(WRK)/_zz_Collection_SubSet_int__Template.obj \
$(WRK)/_zz_Container_List_int__Template.obj \
$(WRK)/_zz_Container_MSet_charp__Template.obj \
$(WRK)/_zz_Container_MSet_int__Template.obj \
$(WRK)/_zz_Container_Sequence_charp__Template.obj \
$(WRK)/_zz_Container_Sequence_int__Template.obj \
$(WRK)/_zz_Container_Set_charp__Template.obj \
$(WRK)/_zz_Container_Set_int__Template.obj \
$(WRK)/_zz_Container_SubSet_int__Template.obj \
$(WRK)/_zz_DList_List_int__Template.obj \
$(WRK)/_zz_DList_MSet_charp__Template.obj \
$(WRK)/_zz_DList_MSet_int__Template.obj \
$(WRK)/_zz_DList_Sequence_charp__Template.obj \
$(WRK)/_zz_DList_Sequence_int__Template.obj \
$(WRK)/_zz_DList_Set_charp__Template.obj \
$(WRK)/_zz_DList_Set_int__Template.obj \
$(WRK)/_zz_DList_SubSet_int__Template.obj \
$(WRK)/_zz_ElementOps_Array_char__Template.obj \
$(WRK)/_zz_ElementOps_Array_charp__Template.obj \
$(WRK)/_zz_ElementOps_Array_double__Template.obj \
$(WRK)/_zz_ElementOps_Array_int__Template.obj \
$(WRK)/_zz_ElementOps_Collection_char__Template.obj \
$(WRK)/_zz_ElementOps_Collection_charp__Template.obj \
$(WRK)/_zz_ElementOps_Collection_double__Template.obj \
$(WRK)/_zz_ElementOps_Collection_int__Template.obj \
$(WRK)/_zz_ElementOps_Container_char__Template.obj \
$(WRK)/_zz_ElementOps_Container_charp__Template.obj \
$(WRK)/_zz_ElementOps_Container_double__Template.obj \
$(WRK)/_zz_ElementOps_Container_int__Template.obj \
$(WRK)/_zz_ElementOps_DList_char__Template.obj \
$(WRK)/_zz_ElementOps_DList_charp__Template.obj \
$(WRK)/_zz_ElementOps_DList_double__Template.obj \
$(WRK)/_zz_ElementOps_DList_int__Template.obj \
$(WRK)/_zz_ElementOps_List_char__Template.obj \
$(WRK)/_zz_ElementOps_List_charp__Template.obj \
$(WRK)/_zz_ElementOps_List_double__Template.obj \
$(WRK)/_zz_ElementOps_List_int__Template.obj \
$(WRK)/_zz_ElementOps_MSet_char__Template.obj \
$(WRK)/_zz_ElementOps_MSet_charp__Template.obj \
$(WRK)/_zz_ElementOps_MSet_double__Template.obj \
$(WRK)/_zz_ElementOps_MSet_int__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_char__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_charp__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_double__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_int__Template.obj \
$(WRK)/_zz_ElementOps_SetFuncs_int__Template.obj \
$(WRK)/_zz_ElementOps_Set_char__Template.obj \
$(WRK)/_zz_ElementOps_Set_charp__Template.obj \
$(WRK)/_zz_ElementOps_Set_double__Template.obj \
$(WRK)/_zz_ElementOps_Set_int__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_char__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_charp__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_double__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_int__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_char__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_charp__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_double__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_int__Template.obj \
$(WRK)/_zz_ElementOps_SubSet_int__Template.obj \
$(WRK)/_zz_Iterator_List_int__Template.obj \
$(WRK)/_zz_Iterator_MSet_charp__Template.obj \
$(WRK)/_zz_Iterator_MSet_int__Template.obj \
$(WRK)/_zz_Iterator_Sequence_charp__Template.obj \
$(WRK)/_zz_Iterator_Sequence_int__Template.obj \
$(WRK)/_zz_Iterator_Set_charp__Template.obj \
$(WRK)/_zz_Iterator_Set_int__Template.obj \
$(WRK)/_zz_Iterator_SubSet_int__Template.obj \
$(WRK)/_zz_List_List_int__Template.obj \
$(WRK)/_zz_List_MSet_charp__Template.obj \
$(WRK)/_zz_List_MSet_int__Template.obj \
$(WRK)/_zz_List_Sequence_charp__Template.obj \
$(WRK)/_zz_List_Sequence_int__Template.obj \
$(WRK)/_zz_List_Set_charp__Template.obj \
$(WRK)/_zz_List_Set_int__Template.obj \
$(WRK)/_zz_List_SubSet_int__Template.obj \
$(WRK)/_zz_MSetBase_char_List_char__Template.obj \
$(WRK)/_zz_MSetBase_char_SortedList_char__Template.obj \
$(WRK)/_zz_MSetBase_charp_List_charp__Template.obj \
$(WRK)/_zz_MSetBase_charp_SortedList_charp__Template.obj \
$(WRK)/_zz_MSetBase_double_List_double__Template.obj \
$(WRK)/_zz_MSetBase_double_SortedList_double__Template.obj \
$(WRK)/_zz_MSetBase_int_List_int__Template.obj \
$(WRK)/_zz_MSetBase_int_SortedList_int__Template.obj \
$(WRK)/_zz_MSet_List_int__Template.obj \
$(WRK)/_zz_MSet_MSet_charp__Template.obj \
$(WRK)/_zz_MSet_MSet_int__Template.obj \
$(WRK)/_zz_MSet_Sequence_charp__Template.obj \
$(WRK)/_zz_MSet_Sequence_int__Template.obj \
$(WRK)/_zz_MSet_Set_charp__Template.obj \
$(WRK)/_zz_MSet_Set_int__Template.obj \
$(WRK)/_zz_MSet_SubSet_int__Template.obj \
$(WRK)/_zz_SequenceBase_char_List_char__Template.obj \
$(WRK)/_zz_SequenceBase_charp_List_charp__Template.obj \
$(WRK)/_zz_SequenceBase_double_List_double__Template.obj \
$(WRK)/_zz_SequenceBase_int_List_int__Template.obj \
$(WRK)/_zz_Sequence_List_int__Template.obj \
$(WRK)/_zz_Sequence_MSet_charp__Template.obj \
$(WRK)/_zz_Sequence_MSet_int__Template.obj \
$(WRK)/_zz_Sequence_Sequence_charp__Template.obj \
$(WRK)/_zz_Sequence_Sequence_int__Template.obj \
$(WRK)/_zz_Sequence_Set_charp__Template.obj \
$(WRK)/_zz_Sequence_Set_int__Template.obj \
$(WRK)/_zz_Sequence_SubSet_int__Template.obj \
$(WRK)/_zz_SetBase_char_SortedList_char__Template.obj \
$(WRK)/_zz_SetBase_charp_SortedList_charp__Template.obj \
$(WRK)/_zz_SetBase_double_SortedList_double__Template.obj \
$(WRK)/_zz_SetBase_int_SortedList_int__Template.obj \
$(WRK)/_zz_Set_List_int__Template.obj \
$(WRK)/_zz_Set_MSet_charp__Template.obj \
$(WRK)/_zz_Set_MSet_int__Template.obj \
$(WRK)/_zz_Set_Sequence_charp__Template.obj \
$(WRK)/_zz_Set_Sequence_int__Template.obj \
$(WRK)/_zz_Set_Set_charp__Template.obj \
$(WRK)/_zz_Set_Set_int__Template.obj \
$(WRK)/_zz_Set_SubSet_int__Template.obj \
$(WRK)/_zz_SimpleContainer_List_int__Template.obj \
$(WRK)/_zz_SimpleContainer_MSet_charp__Template.obj \
$(WRK)/_zz_SimpleContainer_MSet_int__Template.obj \
$(WRK)/_zz_SimpleContainer_Sequence_charp__Template.obj \
$(WRK)/_zz_SimpleContainer_Sequence_int__Template.obj \
$(WRK)/_zz_SimpleContainer_Set_charp__Template.obj \
$(WRK)/_zz_SimpleContainer_Set_int__Template.obj \
$(WRK)/_zz_SimpleContainer_SubSet_int__Template.obj \
$(WRK)/_zz_SortedArray_List_int__Template.obj \
$(WRK)/_zz_SortedArray_MSet_charp__Template.obj \
$(WRK)/_zz_SortedArray_MSet_int__Template.obj \
$(WRK)/_zz_SortedArray_Sequence_charp__Template.obj \
$(WRK)/_zz_SortedArray_Sequence_int__Template.obj \
$(WRK)/_zz_SortedArray_Set_charp__Template.obj \
$(WRK)/_zz_SortedArray_Set_int__Template.obj \
$(WRK)/_zz_SortedArray_SubSet_int__Template.obj \
$(WRK)/_zz_SortedList_List_int__Template.obj \
$(WRK)/_zz_SortedList_MSet_charp__Template.obj \
$(WRK)/_zz_SortedList_MSet_int__Template.obj \
$(WRK)/_zz_SortedList_Sequence_charp__Template.obj \
$(WRK)/_zz_SortedList_Sequence_int__Template.obj \
$(WRK)/_zz_SortedList_Set_charp__Template.obj \
$(WRK)/_zz_SortedList_Set_int__Template.obj \
$(WRK)/_zz_SortedList_SubSet_int__Template.obj \
$(WRK)/_zzz_ElementOps_Array_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_Array_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Array_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_Array_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_Collection_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Container_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_Container_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Container_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_Container_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_DList_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_DList_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_DList_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_DList_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_List_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_List_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_List_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_List_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_List_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_List_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_List_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_List_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_MSet_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_Sequence_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Set_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_Set_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_Set_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_Set_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedArray_SubSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_List_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_MSet_charp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_MSet_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Sequence_charp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Sequence_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Set_charp___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_Set_int___Template.obj \
$(WRK)/_zzz_ElementOps_SortedList_SubSet_int___Template.obj \
$(WRK)/_zzzz_MSetBase_List_int__List_List_int___Template.obj \
$(WRK)/_zzzz_MSetBase_List_int__SortedList_List_int___Template.obj \
$(WRK)/_zzzz_MSetBase_MSet_charp__List_MSet_charp___Template.obj \
$(WRK)/_zzzz_MSetBase_MSet_charp__SortedList_MSet_charp___Template.obj \
$(WRK)/_zzzz_MSetBase_MSet_int__List_MSet_int___Template.obj \
$(WRK)/_zzzz_MSetBase_MSet_int__SortedList_MSet_int___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_charp__List_Sequence_charp___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_charp__SortedList_Sequence_charp___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_int__List_Sequence_int___Template.obj \
$(WRK)/_zzzz_MSetBase_Sequence_int__SortedList_Sequence_int___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_charp__List_Set_charp___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_charp__SortedList_Set_charp___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_int__List_Set_int___Template.obj \
$(WRK)/_zzzz_MSetBase_Set_int__SortedList_Set_int___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_int__List_SubSet_int___Template.obj \
$(WRK)/_zzzz_MSetBase_SubSet_int__SortedList_SubSet_int___Template.obj \
$(WRK)/_zzzz_SequenceBase_List_int__List_List_int___Template.obj \
$(WRK)/_zzzz_SequenceBase_MSet_charp__List_MSet_charp___Template.obj \
$(WRK)/_zzzz_SequenceBase_MSet_int__List_MSet_int___Template.obj \
$(WRK)/_zzzz_SequenceBase_Sequence_charp__List_Sequence_charp___Template.obj \
$(WRK)/_zzzz_SequenceBase_Sequence_int__List_Sequence_int___Template.obj \
$(WRK)/_zzzz_SequenceBase_Set_charp__List_Set_charp___Template.obj \
$(WRK)/_zzzz_SequenceBase_Set_int__List_Set_int___Template.obj \
$(WRK)/_zzzz_SequenceBase_SubSet_int__List_SubSet_int___Template.obj \
$(WRK)/_zzzz_SetBase_List_int__SortedList_List_int___Template.obj \
$(WRK)/_zzzz_SetBase_MSet_charp__SortedList_MSet_charp___Template.obj \
$(WRK)/_zzzz_SetBase_MSet_int__SortedList_MSet_int___Template.obj \
$(WRK)/_zzzz_SetBase_Sequence_charp__SortedList_Sequence_charp___Template.obj \
$(WRK)/_zzzz_SetBase_Sequence_int__SortedList_Sequence_int___Template.obj \
$(WRK)/_zzzz_SetBase_Set_charp__SortedList_Set_charp___Template.obj \
$(WRK)/_zzzz_SetBase_Set_int__SortedList_Set_int___Template.obj \
$(WRK)/_zzzz_SetBase_SubSet_int__SortedList_SubSet_int___Template.obj 


Dep_LinklibstkW = $(WRK)/C++pointer.obj $(WRK)/graphSTkUtils.obj \
$(WRK)/basicSTkUtils.obj \
$(WRK)/stkWrapper.obj 

#Dep_LinklibstkW = $(WRK)/C++pointer.obj \
#$(WRK)/basicSTkUtils.obj \
#$(WRK)/stkWrapper.obj 

Dep_Linklibgraphstk = \
$(WRK)/graphManualSTkFiles.obj \
$(WRK)/graphInitSTkFiles.obj \
$(WRK)/_z_ArrayWrapper_AttributeBasep_Template.obj \
$(WRK)/_z_ArrayWrapper_Edgep_Template.obj \
$(WRK)/_z_ArrayWrapper_Graphp_Template.obj \
$(WRK)/_z_ArrayWrapper_Vertexp_Template.obj \
$(WRK)/_z_CollectionWrapper_AttributeBasep_Template.obj \
$(WRK)/_z_CollectionWrapper_Edgep_Template.obj \
$(WRK)/_z_CollectionWrapper_Graphp_Template.obj \
$(WRK)/_z_CollectionWrapper_Vertexp_Template.obj \
$(WRK)/_z_ListWrapper_AttributeBasep_Template.obj \
$(WRK)/_z_ListWrapper_Edgep_Template.obj \
$(WRK)/_z_ListWrapper_Graphp_Template.obj \
$(WRK)/_z_ListWrapper_Vertexp_Template.obj \
$(WRK)/_z_Register_AttributeBase_Template.obj \
$(WRK)/_z_Register_AttributeBasep_Template.obj \
$(WRK)/_z_Register_BinGraph_Template.obj \
$(WRK)/_z_Register_BinGraphp_Template.obj \
$(WRK)/_z_Register_DBinGraph_Template.obj \
$(WRK)/_z_Register_DBinGraphp_Template.obj \
$(WRK)/_z_Register_DHyperGraph_Template.obj \
$(WRK)/_z_Register_DHyperGraphp_Template.obj \
$(WRK)/_z_Register_Edge_Template.obj \
$(WRK)/_z_Register_Edgep_Template.obj \
$(WRK)/_z_Register_Graph_Template.obj \
$(WRK)/_z_Register_Graphp_Template.obj \
$(WRK)/_z_Register_HyperGraph_Template.obj \
$(WRK)/_z_Register_HyperGraphp_Template.obj \
$(WRK)/_z_Register_MBinGraph_Template.obj \
$(WRK)/_z_Register_MBinGraphp_Template.obj \
$(WRK)/_z_Register_MDBinGraph_Template.obj \
$(WRK)/_z_Register_MDBinGraphp_Template.obj \
$(WRK)/_z_Register_MDHyperGraph_Template.obj \
$(WRK)/_z_Register_MDHyperGraphp_Template.obj \
$(WRK)/_z_Register_MHyperGraph_Template.obj \
$(WRK)/_z_Register_MHyperGraphp_Template.obj \
$(WRK)/_z_Register_MUBinGraph_Template.obj \
$(WRK)/_z_Register_MUBinGraphp_Template.obj \
$(WRK)/_z_Register_MUHyperGraph_Template.obj \
$(WRK)/_z_Register_MUHyperGraphp_Template.obj \
$(WRK)/_z_Register_UBinGraph_Template.obj \
$(WRK)/_z_Register_UBinGraphp_Template.obj \
$(WRK)/_z_Register_UHyperGraph_Template.obj \
$(WRK)/_z_Register_UHyperGraphp_Template.obj \
$(WRK)/_z_Register_Vertex_Template.obj \
$(WRK)/_z_Register_Vertexp_Template.obj \
$(WRK)/_z_SetFuncsWrapper_AttributeBasep_Template.obj \
$(WRK)/_z_SetFuncsWrapper_Edgep_Template.obj \
$(WRK)/_z_SetFuncsWrapper_Vertexp_Template.obj \
$(WRK)/_z_Wrapper_AttributeBase_Template.obj \
$(WRK)/_z_Wrapper_AttributeBasep_Template.obj \
$(WRK)/_z_Wrapper_BinGraph_Template.obj \
$(WRK)/_z_Wrapper_BinGraphp_Template.obj \
$(WRK)/_z_Wrapper_DBinGraph_Template.obj \
$(WRK)/_z_Wrapper_DBinGraphp_Template.obj \
$(WRK)/_z_Wrapper_DHyperGraph_Template.obj \
$(WRK)/_z_Wrapper_DHyperGraphp_Template.obj \
$(WRK)/_z_Wrapper_Edge_Template.obj \
$(WRK)/_z_Wrapper_Edgep_Template.obj \
$(WRK)/_z_Wrapper_Graph_Template.obj \
$(WRK)/_z_Wrapper_Graphp_Template.obj \
$(WRK)/_z_Wrapper_HyperGraph_Template.obj \
$(WRK)/_z_Wrapper_HyperGraphp_Template.obj \
$(WRK)/_z_Wrapper_MBinGraph_Template.obj \
$(WRK)/_z_Wrapper_MBinGraphp_Template.obj \
$(WRK)/_z_Wrapper_MDBinGraph_Template.obj \
$(WRK)/_z_Wrapper_MDBinGraphp_Template.obj \
$(WRK)/_z_Wrapper_MDHyperGraph_Template.obj \
$(WRK)/_z_Wrapper_MDHyperGraphp_Template.obj \
$(WRK)/_z_Wrapper_MHyperGraph_Template.obj \
$(WRK)/_z_Wrapper_MHyperGraphp_Template.obj \
$(WRK)/_z_Wrapper_MUBinGraph_Template.obj \
$(WRK)/_z_Wrapper_MUBinGraphp_Template.obj \
$(WRK)/_z_Wrapper_MUHyperGraph_Template.obj \
$(WRK)/_z_Wrapper_MUHyperGraphp_Template.obj \
$(WRK)/_z_Wrapper_UBinGraph_Template.obj \
$(WRK)/_z_Wrapper_UBinGraphp_Template.obj \
$(WRK)/_z_Wrapper_UHyperGraph_Template.obj \
$(WRK)/_z_Wrapper_UHyperGraphp_Template.obj \
$(WRK)/_z_Wrapper_Vertex_Template.obj \
$(WRK)/_z_Wrapper_Vertexp_Template.obj \
$(WRK)/_zz_ArrayWrapper_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_ArrayWrapper_Sequence_Edgep__Template.obj \
$(WRK)/_zz_ArrayWrapper_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_ArrayWrapper_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_ArrayWrapper_Set_Edgep__Template.obj \
$(WRK)/_zz_ArrayWrapper_Set_Vertexp__Template.obj \
$(WRK)/_zz_ArrayWrapper_SubSet_Edgep__Template.obj \
$(WRK)/_zz_ArrayWrapper_SubSet_Graphp__Template.obj \
$(WRK)/_zz_ArrayWrapper_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_CollectionWrapper_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_CollectionWrapper_Sequence_Edgep__Template.obj \
$(WRK)/_zz_CollectionWrapper_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_CollectionWrapper_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_CollectionWrapper_Set_Edgep__Template.obj \
$(WRK)/_zz_CollectionWrapper_Set_Vertexp__Template.obj \
$(WRK)/_zz_CollectionWrapper_SubSet_Edgep__Template.obj \
$(WRK)/_zz_CollectionWrapper_SubSet_Graphp__Template.obj \
$(WRK)/_zz_CollectionWrapper_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_ListWrapper_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_ListWrapper_Sequence_Edgep__Template.obj \
$(WRK)/_zz_ListWrapper_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_ListWrapper_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_ListWrapper_Set_Edgep__Template.obj \
$(WRK)/_zz_ListWrapper_Set_Vertexp__Template.obj \
$(WRK)/_zz_ListWrapper_SubSet_Edgep__Template.obj \
$(WRK)/_zz_ListWrapper_SubSet_Graphp__Template.obj \
$(WRK)/_zz_ListWrapper_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_Register_Array_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_Array_Edgep__Template.obj \
$(WRK)/_zz_Register_Array_Graphp__Template.obj \
$(WRK)/_zz_Register_Array_Vertexp__Template.obj \
$(WRK)/_zz_Register_Attribute_ContainerNodep__Template.obj \
$(WRK)/_zz_Register_Attribute_ContainerNodep_p_Template.obj \
$(WRK)/_zz_Register_Attribute_Edgep__Template.obj \
$(WRK)/_zz_Register_Attribute_Edgep_p_Template.obj \
$(WRK)/_zz_Register_Attribute_GraphObjectp__Template.obj \
$(WRK)/_zz_Register_Attribute_GraphObjectp_p_Template.obj \
$(WRK)/_zz_Register_Attribute_Graphp__Template.obj \
$(WRK)/_zz_Register_Attribute_Graphp_p_Template.obj \
$(WRK)/_zz_Register_Attribute_String__Template.obj \
$(WRK)/_zz_Register_Attribute_String_p_Template.obj \
$(WRK)/_zz_Register_Attribute_Vertexp__Template.obj \
$(WRK)/_zz_Register_Attribute_Vertexp_p_Template.obj \
$(WRK)/_zz_Register_Attribute_char__Template.obj \
$(WRK)/_zz_Register_Attribute_char_p_Template.obj \
$(WRK)/_zz_Register_Attribute_double__Template.obj \
$(WRK)/_zz_Register_Attribute_double_p_Template.obj \
$(WRK)/_zz_Register_Attribute_float__Template.obj \
$(WRK)/_zz_Register_Attribute_float_p_Template.obj \
$(WRK)/_zz_Register_Attribute_int__Template.obj \
$(WRK)/_zz_Register_Attribute_int_p_Template.obj \
$(WRK)/_zz_Register_Collection_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_Collection_Edgep__Template.obj \
$(WRK)/_zz_Register_Collection_Graphp__Template.obj \
$(WRK)/_zz_Register_Collection_Vertexp__Template.obj \
$(WRK)/_zz_Register_Container_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_Container_Edgep__Template.obj \
$(WRK)/_zz_Register_Container_Graphp__Template.obj \
$(WRK)/_zz_Register_Container_Vertexp__Template.obj \
$(WRK)/_zz_Register_DList_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_DList_Edgep__Template.obj \
$(WRK)/_zz_Register_DList_Graphp__Template.obj \
$(WRK)/_zz_Register_DList_Vertexp__Template.obj \
$(WRK)/_zz_Register_List_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_List_Edgep__Template.obj \
$(WRK)/_zz_Register_List_Graphp__Template.obj \
$(WRK)/_zz_Register_List_Vertexp__Template.obj \
$(WRK)/_zz_Register_MSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_MSet_Edgep__Template.obj \
$(WRK)/_zz_Register_MSet_Graphp__Template.obj \
$(WRK)/_zz_Register_MSet_Vertexp__Template.obj \
$(WRK)/_zz_Register_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Register_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Register_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Register_SetFuncs_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_SetFuncs_Edgep__Template.obj \
$(WRK)/_zz_Register_SetFuncs_Vertexp__Template.obj \
$(WRK)/_zz_Register_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_Set_Edgep__Template.obj \
$(WRK)/_zz_Register_Set_Graphp__Template.obj \
$(WRK)/_zz_Register_Set_Vertexp__Template.obj \
$(WRK)/_zz_Register_SortedArray_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_SortedArray_Edgep__Template.obj \
$(WRK)/_zz_Register_SortedArray_Graphp__Template.obj \
$(WRK)/_zz_Register_SortedArray_Vertexp__Template.obj \
$(WRK)/_zz_Register_SortedList_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_SortedList_Edgep__Template.obj \
$(WRK)/_zz_Register_SortedList_Graphp__Template.obj \
$(WRK)/_zz_Register_SortedList_Vertexp__Template.obj \
$(WRK)/_zz_Register_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Register_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Register_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Register_SubSet_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_Array_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_Array_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_Array_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_Array_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_ContainerNodep__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_ContainerNodep_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_Edgep_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_GraphObjectp__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_GraphObjectp_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_Graphp_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_String__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_String_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_Vertexp_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_char__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_char_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_double__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_double_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_float__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_float_p_Template.obj \
$(WRK)/_zz_Wrapper_Attribute_int__Template.obj \
$(WRK)/_zz_Wrapper_Attribute_int_p_Template.obj \
$(WRK)/_zz_Wrapper_Collection_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_Collection_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_Collection_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_Collection_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_Container_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_Container_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_Container_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_Container_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_DList_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_DList_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_DList_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_DList_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_List_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_List_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_List_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_List_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_MSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_MSet_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_MSet_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_MSet_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_SetFuncs_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_SetFuncs_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_SetFuncs_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_Set_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_Set_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_Set_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_Set_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_Vertexp__Template.obj \
$(WRK)/_zz_Wrapper_SubSet_AttributeBasep__Template.obj \
$(WRK)/_zz_Wrapper_SubSet_Edgep__Template.obj \
$(WRK)/_zz_Wrapper_SubSet_Graphp__Template.obj \
$(WRK)/_zz_Wrapper_SubSet_Vertexp__Template.obj \
$(WRK)/_zzz_Register_Array_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Array_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_Array_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Array_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Array_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_Array_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Array_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_Array_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_Array_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Attribute_DList_Vertexp_p__Template.obj \
$(WRK)/_zzz_Register_Attribute_DList_Vertexp_p_p_Template.obj \
$(WRK)/_zzz_Register_Attribute_List_Vertexp_p__Template.obj \
$(WRK)/_zzz_Register_Attribute_List_Vertexp_p_p_Template.obj \
$(WRK)/_zzz_Register_Collection_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Collection_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_Collection_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Collection_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Collection_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_Collection_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Collection_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_Collection_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_Collection_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Container_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Container_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_Container_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Container_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Container_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_Container_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Container_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_Container_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_Container_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_DList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_DList_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_DList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_DList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_DList_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_DList_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_DList_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_DList_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_DList_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_List_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_List_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_List_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_List_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_List_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_List_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_List_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_List_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_List_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_MSet_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_MSet_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_MSet_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_MSet_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_MSet_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_MSet_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_MSet_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_MSet_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_MSet_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Sequence_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Sequence_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_Sequence_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Sequence_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Sequence_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_Sequence_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Sequence_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_Sequence_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_Sequence_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Set_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Set_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_Set_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Set_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_Set_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_Set_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_Set_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_Set_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_Set_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_SortedArray_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_SortedArray_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_SortedArray_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Register_SortedList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_SortedList_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Register_SortedList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Register_SortedList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Register_SortedList_Set_Edgep___Template.obj \
$(WRK)/_zzz_Register_SortedList_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Register_SortedList_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Register_SortedList_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Register_SortedList_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Array_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Array_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_Array_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Attribute_DList_Vertexp_p__Template.obj \
$(WRK)/_zzz_Wrapper_Attribute_DList_Vertexp_p_p_Template.obj \
$(WRK)/_zzz_Wrapper_Attribute_List_Vertexp_p__Template.obj \
$(WRK)/_zzz_Wrapper_Attribute_List_Vertexp_p_p_Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Container_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Container_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_Container_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_DList_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_DList_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_DList_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_List_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_List_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_List_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_List_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_List_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_List_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_List_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_List_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_List_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_Set_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_Set_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_Set_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_SubSet_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Sequence_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Sequence_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Sequence_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Set_AttributeBasep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Set_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Set_Vertexp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_SubSet_Edgep___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_SubSet_Graphp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_SubSet_Vertexp___Template.obj 


Dep_Linklibbasicstk = \
$(WRK)/basicManualSTkFiles.obj \
$(WRK)/basicInitSTkFiles.obj \
$(WRK)/_z_ArrayWrapper_char_Template.obj \
$(WRK)/_z_ArrayWrapper_charp_Template.obj \
$(WRK)/_z_ArrayWrapper_double_Template.obj \
$(WRK)/_z_ArrayWrapper_doublep_Template.obj \
$(WRK)/_z_ArrayWrapper_int_Template.obj \
$(WRK)/_z_CollectionWrapper_char_Template.obj \
$(WRK)/_z_CollectionWrapper_charp_Template.obj \
$(WRK)/_z_CollectionWrapper_double_Template.obj \
$(WRK)/_z_CollectionWrapper_doublep_Template.obj \
$(WRK)/_z_CollectionWrapper_int_Template.obj \
$(WRK)/_z_ListWrapper_char_Template.obj \
$(WRK)/_z_ListWrapper_charp_Template.obj \
$(WRK)/_z_ListWrapper_double_Template.obj \
$(WRK)/_z_ListWrapper_doublep_Template.obj \
$(WRK)/_z_ListWrapper_int_Template.obj \
$(WRK)/_z_MatrixWrapper_double_Template.obj \
$(WRK)/_z_MatrixWrapper_int_Template.obj \
$(WRK)/_z_Register_char_Template.obj \
$(WRK)/_z_Register_charp_Template.obj \
$(WRK)/_z_Register_double_Template.obj \
$(WRK)/_z_Register_doublep_Template.obj \
$(WRK)/_z_Register_int_Template.obj \
$(WRK)/_z_SetFuncsWrapper_int_Template.obj \
$(WRK)/_z_Wrapper_char_Template.obj \
$(WRK)/_z_Wrapper_charp_Template.obj \
$(WRK)/_z_Wrapper_double_Template.obj \
$(WRK)/_z_Wrapper_doublep_Template.obj \
$(WRK)/_z_Wrapper_int_Template.obj \
$(WRK)/_zz_ArrayWrapper_MSet_charp__Template.obj \
$(WRK)/_zz_ArrayWrapper_MSet_int__Template.obj \
$(WRK)/_zz_ArrayWrapper_Sequence_charp__Template.obj \
$(WRK)/_zz_ArrayWrapper_Sequence_int__Template.obj \
$(WRK)/_zz_ArrayWrapper_Set_charp__Template.obj \
$(WRK)/_zz_ArrayWrapper_Set_int__Template.obj \
$(WRK)/_zz_ArrayWrapper_SubSet_int__Template.obj \
$(WRK)/_zz_CollectionWrapper_MSet_charp__Template.obj \
$(WRK)/_zz_CollectionWrapper_MSet_int__Template.obj \
$(WRK)/_zz_CollectionWrapper_Sequence_charp__Template.obj \
$(WRK)/_zz_CollectionWrapper_Sequence_int__Template.obj \
$(WRK)/_zz_CollectionWrapper_Set_charp__Template.obj \
$(WRK)/_zz_CollectionWrapper_Set_int__Template.obj \
$(WRK)/_zz_CollectionWrapper_SubSet_int__Template.obj \
$(WRK)/_zz_ListWrapper_MSet_charp__Template.obj \
$(WRK)/_zz_ListWrapper_MSet_int__Template.obj \
$(WRK)/_zz_ListWrapper_Sequence_charp__Template.obj \
$(WRK)/_zz_ListWrapper_Sequence_int__Template.obj \
$(WRK)/_zz_ListWrapper_Set_charp__Template.obj \
$(WRK)/_zz_ListWrapper_Set_int__Template.obj \
$(WRK)/_zz_ListWrapper_SubSet_int__Template.obj \
$(WRK)/_zz_Register_Array_char__Template.obj \
$(WRK)/_zz_Register_Array_charp__Template.obj \
$(WRK)/_zz_Register_Array_double__Template.obj \
$(WRK)/_zz_Register_Array_doublep__Template.obj \
$(WRK)/_zz_Register_Array_int__Template.obj \
$(WRK)/_zz_Register_Collection_char__Template.obj \
$(WRK)/_zz_Register_Collection_charp__Template.obj \
$(WRK)/_zz_Register_Collection_double__Template.obj \
$(WRK)/_zz_Register_Collection_doublep__Template.obj \
$(WRK)/_zz_Register_Collection_int__Template.obj \
$(WRK)/_zz_Register_Container_char__Template.obj \
$(WRK)/_zz_Register_Container_charp__Template.obj \
$(WRK)/_zz_Register_Container_double__Template.obj \
$(WRK)/_zz_Register_Container_doublep__Template.obj \
$(WRK)/_zz_Register_Container_int__Template.obj \
$(WRK)/_zz_Register_DList_char__Template.obj \
$(WRK)/_zz_Register_DList_charp__Template.obj \
$(WRK)/_zz_Register_DList_double__Template.obj \
$(WRK)/_zz_Register_DList_doublep__Template.obj \
$(WRK)/_zz_Register_DList_int__Template.obj \
$(WRK)/_zz_Register_List_char__Template.obj \
$(WRK)/_zz_Register_List_charp__Template.obj \
$(WRK)/_zz_Register_List_double__Template.obj \
$(WRK)/_zz_Register_List_doublep__Template.obj \
$(WRK)/_zz_Register_List_int__Template.obj \
$(WRK)/_zz_Register_MSet_char__Template.obj \
$(WRK)/_zz_Register_MSet_charp__Template.obj \
$(WRK)/_zz_Register_MSet_double__Template.obj \
$(WRK)/_zz_Register_MSet_doublep__Template.obj \
$(WRK)/_zz_Register_MSet_int__Template.obj \
$(WRK)/_zz_Register_Matrix_double__Template.obj \
$(WRK)/_zz_Register_Matrix_int__Template.obj \
$(WRK)/_zz_Register_Sequence_char__Template.obj \
$(WRK)/_zz_Register_Sequence_charp__Template.obj \
$(WRK)/_zz_Register_Sequence_double__Template.obj \
$(WRK)/_zz_Register_Sequence_doublep__Template.obj \
$(WRK)/_zz_Register_Sequence_int__Template.obj \
$(WRK)/_zz_Register_SetFuncs_int__Template.obj \
$(WRK)/_zz_Register_Set_char__Template.obj \
$(WRK)/_zz_Register_Set_charp__Template.obj \
$(WRK)/_zz_Register_Set_double__Template.obj \
$(WRK)/_zz_Register_Set_doublep__Template.obj \
$(WRK)/_zz_Register_Set_int__Template.obj \
$(WRK)/_zz_Register_SortedArray_char__Template.obj \
$(WRK)/_zz_Register_SortedArray_charp__Template.obj \
$(WRK)/_zz_Register_SortedArray_double__Template.obj \
$(WRK)/_zz_Register_SortedArray_doublep__Template.obj \
$(WRK)/_zz_Register_SortedArray_int__Template.obj \
$(WRK)/_zz_Register_SortedList_char__Template.obj \
$(WRK)/_zz_Register_SortedList_charp__Template.obj \
$(WRK)/_zz_Register_SortedList_double__Template.obj \
$(WRK)/_zz_Register_SortedList_doublep__Template.obj \
$(WRK)/_zz_Register_SortedList_int__Template.obj \
$(WRK)/_zz_Register_SubSet_int__Template.obj \
$(WRK)/_zz_Wrapper_Array_char__Template.obj \
$(WRK)/_zz_Wrapper_Array_charp__Template.obj \
$(WRK)/_zz_Wrapper_Array_double__Template.obj \
$(WRK)/_zz_Wrapper_Array_doublep__Template.obj \
$(WRK)/_zz_Wrapper_Array_int__Template.obj \
$(WRK)/_zz_Wrapper_Collection_char__Template.obj \
$(WRK)/_zz_Wrapper_Collection_charp__Template.obj \
$(WRK)/_zz_Wrapper_Collection_double__Template.obj \
$(WRK)/_zz_Wrapper_Collection_doublep__Template.obj \
$(WRK)/_zz_Wrapper_Collection_int__Template.obj \
$(WRK)/_zz_Wrapper_Container_char__Template.obj \
$(WRK)/_zz_Wrapper_Container_charp__Template.obj \
$(WRK)/_zz_Wrapper_Container_double__Template.obj \
$(WRK)/_zz_Wrapper_Container_doublep__Template.obj \
$(WRK)/_zz_Wrapper_Container_int__Template.obj \
$(WRK)/_zz_Wrapper_DList_char__Template.obj \
$(WRK)/_zz_Wrapper_DList_charp__Template.obj \
$(WRK)/_zz_Wrapper_DList_double__Template.obj \
$(WRK)/_zz_Wrapper_DList_doublep__Template.obj \
$(WRK)/_zz_Wrapper_DList_int__Template.obj \
$(WRK)/_zz_Wrapper_List_char__Template.obj \
$(WRK)/_zz_Wrapper_List_charp__Template.obj \
$(WRK)/_zz_Wrapper_List_double__Template.obj \
$(WRK)/_zz_Wrapper_List_doublep__Template.obj \
$(WRK)/_zz_Wrapper_List_int__Template.obj \
$(WRK)/_zz_Wrapper_MSet_char__Template.obj \
$(WRK)/_zz_Wrapper_MSet_charp__Template.obj \
$(WRK)/_zz_Wrapper_MSet_double__Template.obj \
$(WRK)/_zz_Wrapper_MSet_doublep__Template.obj \
$(WRK)/_zz_Wrapper_MSet_int__Template.obj \
$(WRK)/_zz_Wrapper_Matrix_double__Template.obj \
$(WRK)/_zz_Wrapper_Matrix_int__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_char__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_charp__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_double__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_doublep__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_int__Template.obj \
$(WRK)/_zz_Wrapper_SetFuncs_int__Template.obj \
$(WRK)/_zz_Wrapper_Set_char__Template.obj \
$(WRK)/_zz_Wrapper_Set_charp__Template.obj \
$(WRK)/_zz_Wrapper_Set_double__Template.obj \
$(WRK)/_zz_Wrapper_Set_doublep__Template.obj \
$(WRK)/_zz_Wrapper_Set_int__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_char__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_charp__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_double__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_doublep__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_int__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_char__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_charp__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_double__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_doublep__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_int__Template.obj \
$(WRK)/_zz_Wrapper_SubSet_int__Template.obj \
$(WRK)/_zzz_Register_Array_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_Array_MSet_int___Template.obj \
$(WRK)/_zzz_Register_Array_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_Array_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_Array_Set_charp___Template.obj \
$(WRK)/_zzz_Register_Array_Set_int___Template.obj \
$(WRK)/_zzz_Register_Array_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_Collection_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_Collection_MSet_int___Template.obj \
$(WRK)/_zzz_Register_Collection_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_Collection_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_Collection_Set_charp___Template.obj \
$(WRK)/_zzz_Register_Collection_Set_int___Template.obj \
$(WRK)/_zzz_Register_Collection_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_Container_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_Container_MSet_int___Template.obj \
$(WRK)/_zzz_Register_Container_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_Container_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_Container_Set_charp___Template.obj \
$(WRK)/_zzz_Register_Container_Set_int___Template.obj \
$(WRK)/_zzz_Register_Container_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_DList_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_DList_MSet_int___Template.obj \
$(WRK)/_zzz_Register_DList_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_DList_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_DList_Set_charp___Template.obj \
$(WRK)/_zzz_Register_DList_Set_int___Template.obj \
$(WRK)/_zzz_Register_DList_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_List_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_List_MSet_int___Template.obj \
$(WRK)/_zzz_Register_List_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_List_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_List_Set_charp___Template.obj \
$(WRK)/_zzz_Register_List_Set_int___Template.obj \
$(WRK)/_zzz_Register_List_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_MSet_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_MSet_MSet_int___Template.obj \
$(WRK)/_zzz_Register_MSet_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_MSet_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_MSet_Set_charp___Template.obj \
$(WRK)/_zzz_Register_MSet_Set_int___Template.obj \
$(WRK)/_zzz_Register_MSet_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_Sequence_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_Sequence_MSet_int___Template.obj \
$(WRK)/_zzz_Register_Sequence_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_Sequence_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_Sequence_Set_charp___Template.obj \
$(WRK)/_zzz_Register_Sequence_Set_int___Template.obj \
$(WRK)/_zzz_Register_Sequence_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_Set_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_Set_MSet_int___Template.obj \
$(WRK)/_zzz_Register_Set_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_Set_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_Set_Set_charp___Template.obj \
$(WRK)/_zzz_Register_Set_Set_int___Template.obj \
$(WRK)/_zzz_Register_Set_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_SortedArray_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_SortedArray_MSet_int___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Set_charp___Template.obj \
$(WRK)/_zzz_Register_SortedArray_Set_int___Template.obj \
$(WRK)/_zzz_Register_SortedArray_SubSet_int___Template.obj \
$(WRK)/_zzz_Register_SortedList_MSet_charp___Template.obj \
$(WRK)/_zzz_Register_SortedList_MSet_int___Template.obj \
$(WRK)/_zzz_Register_SortedList_Sequence_charp___Template.obj \
$(WRK)/_zzz_Register_SortedList_Sequence_int___Template.obj \
$(WRK)/_zzz_Register_SortedList_Set_charp___Template.obj \
$(WRK)/_zzz_Register_SortedList_Set_int___Template.obj \
$(WRK)/_zzz_Register_SortedList_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Array_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Array_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Array_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_Array_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_Collection_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Container_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Container_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Container_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_Container_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_DList_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_DList_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_DList_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_DList_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_List_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_List_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_List_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_List_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_List_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_List_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_List_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_MSet_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_Sequence_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Set_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Set_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_Set_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_Set_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedArray_SubSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_MSet_charp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_MSet_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Sequence_charp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Sequence_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Set_charp___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_Set_int___Template.obj \
$(WRK)/_zzz_Wrapper_SortedList_SubSet_int___Template.obj 


Dep_Linklibuserobjstk = \
$(WRK)/userobjManualSTkFiles.obj \
$(WRK)/userobjInitSTkFiles.obj \
$(WRK)/_z_ArrayWrapper_Testobj_Template.obj \
$(WRK)/_z_ArrayWrapper_Testobjp_Template.obj \
$(WRK)/_z_CollectionWrapper_Testobj_Template.obj \
$(WRK)/_z_CollectionWrapper_Testobjp_Template.obj \
$(WRK)/_z_ListWrapper_Testobj_Template.obj \
$(WRK)/_z_ListWrapper_Testobjp_Template.obj \
$(WRK)/_z_Register_Testobj_Template.obj \
$(WRK)/_z_Register_Testobjp_Template.obj \
$(WRK)/_z_Wrapper_Testobj_Template.obj \
$(WRK)/_z_Wrapper_Testobjp_Template.obj \
$(WRK)/_zz_Register_Array_Testobj__Template.obj \
$(WRK)/_zz_Register_Array_Testobjp__Template.obj \
$(WRK)/_zz_Register_Collection_Testobj__Template.obj \
$(WRK)/_zz_Register_Collection_Testobjp__Template.obj \
$(WRK)/_zz_Register_Container_Testobj__Template.obj \
$(WRK)/_zz_Register_Container_Testobjp__Template.obj \
$(WRK)/_zz_Register_DList_Testobj__Template.obj \
$(WRK)/_zz_Register_DList_Testobjp__Template.obj \
$(WRK)/_zz_Register_List_Testobj__Template.obj \
$(WRK)/_zz_Register_List_Testobjp__Template.obj \
$(WRK)/_zz_Register_MSet_Testobj__Template.obj \
$(WRK)/_zz_Register_MSet_Testobjp__Template.obj \
$(WRK)/_zz_Register_Sequence_Testobj__Template.obj \
$(WRK)/_zz_Register_Sequence_Testobjp__Template.obj \
$(WRK)/_zz_Register_Set_Testobj__Template.obj \
$(WRK)/_zz_Register_Set_Testobjp__Template.obj \
$(WRK)/_zz_Register_SortedArray_Testobj__Template.obj \
$(WRK)/_zz_Register_SortedArray_Testobjp__Template.obj \
$(WRK)/_zz_Register_SortedList_Testobj__Template.obj \
$(WRK)/_zz_Register_SortedList_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_Array_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_Array_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_Collection_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_Collection_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_Container_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_Container_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_DList_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_DList_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_List_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_List_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_MSet_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_MSet_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_Sequence_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_Set_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_Set_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_SortedArray_Testobjp__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_Testobj__Template.obj \
$(WRK)/_zz_Wrapper_SortedList_Testobjp__Template.obj 


Dep_Linkuserobjlib =  \
$(WRK)/Extract.obj \
$(WRK)/ExtractMaximalClique.obj \
$(WRK)/ExtractNGInducedGraph.obj \
$(WRK)/Extract_SaveGraphs.obj \
$(WRK)/FindDistribution.obj \
$(WRK)/GetNumbers.obj \
$(WRK)/InitPost.obj \
$(WRK)/PartitioningLayout.obj \
$(WRK)/PlacedPartitions.obj \
$(WRK)/PostAnalyze.obj \
$(WRK)/Testobj.obj \
$(WRK)/_z_Array_AnimationDatap_Template.obj \
$(WRK)/_z_Array_Testobj_Template.obj \
$(WRK)/_z_Array_Testobjp_Template.obj \
$(WRK)/_z_Collection_AnimationDatap_Template.obj \
$(WRK)/_z_Collection_Testobj_Template.obj \
$(WRK)/_z_Collection_Testobjp_Template.obj \
$(WRK)/_z_Container_AnimationDatap_Template.obj \
$(WRK)/_z_Container_Testobj_Template.obj \
$(WRK)/_z_Container_Testobjp_Template.obj \
$(WRK)/_z_DList_AnimationDatap_Template.obj \
$(WRK)/_z_DList_Testobj_Template.obj \
$(WRK)/_z_DList_Testobjp_Template.obj \
$(WRK)/_z_ElementOps_AnimationData_Template.obj \
$(WRK)/_z_ElementOps_AnimationDatap_Template.obj \
$(WRK)/_z_ElementOps_Testobj_Template.obj \
$(WRK)/_z_ElementOps_Testobjp_Template.obj \
$(WRK)/_z_Iterator_AnimationDatap_Template.obj \
$(WRK)/_z_Iterator_Testobj_Template.obj \
$(WRK)/_z_Iterator_Testobjp_Template.obj \
$(WRK)/_z_List_AnimationDatap_Template.obj \
$(WRK)/_z_List_Testobj_Template.obj \
$(WRK)/_z_List_Testobjp_Template.obj \
$(WRK)/_z_MSet_AnimationDatap_Template.obj \
$(WRK)/_z_MSet_Testobj_Template.obj \
$(WRK)/_z_MSet_Testobjp_Template.obj \
$(WRK)/_z_Sequence_AnimationDatap_Template.obj \
$(WRK)/_z_Sequence_Testobj_Template.obj \
$(WRK)/_z_Sequence_Testobjp_Template.obj \
$(WRK)/_z_Set_AnimationDatap_Template.obj \
$(WRK)/_z_Set_Testobj_Template.obj \
$(WRK)/_z_Set_Testobjp_Template.obj \
$(WRK)/_z_SimpleContainer_AnimationDatap_Template.obj \
$(WRK)/_z_SimpleContainer_Testobj_Template.obj \
$(WRK)/_z_SimpleContainer_Testobjp_Template.obj \
$(WRK)/_z_SortedArray_AnimationDatap_Template.obj \
$(WRK)/_z_SortedArray_Testobj_Template.obj \
$(WRK)/_z_SortedArray_Testobjp_Template.obj \
$(WRK)/_z_SortedList_AnimationDatap_Template.obj \
$(WRK)/_z_SortedList_Testobj_Template.obj \
$(WRK)/_z_SortedList_Testobjp_Template.obj \
$(WRK)/_zz_ElementOps_Array_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_Array_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_Array_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_Collection_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_Collection_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_Collection_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_Container_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_Container_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_Container_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_DList_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_DList_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_DList_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_List_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_List_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_List_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_MSet_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_MSet_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_MSet_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_Sequence_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_Set_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_Set_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_Set_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_SortedArray_Testobjp__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_AnimationDatap__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_Testobj__Template.obj \
$(WRK)/_zz_ElementOps_SortedList_Testobjp__Template.obj \
$(WRK)/_zz_MSetBase_AnimationDatap_List_AnimationDatap__Template.obj \
$(WRK)/_zz_MSetBase_AnimationDatap_SortedList_AnimationDatap__Template.obj \
$(WRK)/_zz_MSetBase_Testobj_List_Testobj__Template.obj \
$(WRK)/_zz_MSetBase_Testobj_SortedList_Testobj__Template.obj \
$(WRK)/_zz_MSetBase_Testobjp_List_Testobjp__Template.obj \
$(WRK)/_zz_MSetBase_Testobjp_SortedList_Testobjp__Template.obj \
$(WRK)/_zz_SequenceBase_AnimationDatap_List_AnimationDatap__Template.obj \
$(WRK)/_zz_SequenceBase_Testobj_List_Testobj__Template.obj \
$(WRK)/_zz_SequenceBase_Testobjp_List_Testobjp__Template.obj \
$(WRK)/_zz_SetBase_AnimationDatap_SortedList_AnimationDatap__Template.obj \
$(WRK)/_zz_SetBase_Testobj_SortedList_Testobj__Template.obj \
$(WRK)/_zz_SetBase_Testobjp_SortedList_Testobjp__Template.obj 


Dep_Linkalglib =  \
$(WRK)/Animation.obj \
$(WRK)/AnimationData.obj \
$(WRK)/ArticulationPoints.obj \
$(WRK)/BiconnectedComponents.obj \
$(WRK)/BreadthFirstSearch.obj \
$(WRK)/Bridges.obj \
$(WRK)/DepthFirstSearch.obj \
$(WRK)/Dijkstra.obj \
$(WRK)/Fleury.obj \
$(WRK)/FloydWarshall.obj \
$(WRK)/Girth.obj \
$(WRK)/GoldbergTarjan.obj \
$(WRK)/HamiltonianCycles.obj \
$(WRK)/KLFM.obj \
$(WRK)/Kruskal.obj \
$(WRK)/Partitioning.obj \
$(WRK)/Prim.obj \
$(WRK)/RevealEdgesByRank.obj \
$(WRK)/ResetAttributes.obj \
$(WRK)/RevealEdgesByRank.obj \
$(WRK)/StronglyConnectedComponents.obj \
$(WRK)/Triangles.obj \
$(WRK)/algorithmTemplate.obj\
$(WRK)/TopologicalSort.obj 


#$(WRK)/Partitioning.obj \
#$(WRK)/KLFM.obj \
#$(WRK)/TopologicalSort.obj \

Dep_Linkalglibstk =  $(WRK)/algorithmSTkInit.obj \
                     $(WRK)/algManualSTkWrappers.obj

Dep_Linkgenlib = \
$(WRK)/GenCompleteGraph.obj \
$(WRK)/GenCycle.obj \
$(WRK)/GenGridGraph.obj \
$(WRK)/GenLatkaTournament.obj \
$(WRK)/GenPrufer.obj \
$(WRK)/GenRegularGraph.obj \
$(WRK)/GenRandomGraph.obj \
$(WRK)/GenUHyperKU.obj 


Dep_Linkgenlibstk = $(WRK)/generatorSTkInit.obj \
                    $(WRK)/genManualSTkWrappers.obj

Dep_Linklaylib = \
$(WRK)/CircleLayout.obj \
$(WRK)/ComponentLayout.obj \
$(WRK)/ComponentLayout2.obj \
$(WRK)/DFSLayout.obj \
$(WRK)/GridLayout.obj \
$(WRK)/HyperBipartiteLayout.obj \
$(WRK)/HyperSpringLayout.obj \
$(WRK)/LayoutUtils.obj \
$(WRK)/RandomLayout.obj \
$(WRK)/SpringLayout.obj 

Dep_Linklaylibstk = $(WRK)/layoutSTkInit.obj \
		    $(WRK)/layoutManualSTkWrappers.obj


Dep_Linkextlibstk =  $(WRK)/extensionSTkInit.obj 

Dep_Linkuserobjlibstk =  $(WRK)/userobjSTkInit.obj \
		  $(Dep_Linklibuserobjstk) 

Dep_Linkgraphlibstk =  $(WRK)/graphSTkInit.obj \
		  $(Dep_Linklibgraphstk) 

Dep_Linkbasiclibstk =  $(WRK)/basicSTkInit.obj \
		  $(Dep_Linklibbasicstk)  \
                  $(Dep_LinklibstkW)


Linkalgstk.lib : $(Dep_Linkalglibstk)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkalglibstk)

Linkalg.lib : $(Dep_Linkalglib)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkalglib)

Linkgenstk.lib : $(Dep_Linkgenlibstk)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkgenlibstk)

Linkgen.lib : $(Dep_Linkgenlib)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkgenlib)

Linklaystk.lib : $(Dep_Linklaylibstk)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linklaylibstk)

Linklay.lib : $(Dep_Linklaylib)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linklaylib)

Linkuserobjstk.lib : $(Dep_Linkuserobjlibstk) $(Dep_Linkextlibstk)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkuserobjlibstk) $(Dep_Linkextlibstk)

Linkuserobj.lib : $(Dep_Linkuserobjlib)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkuserobjlib)

Linkgraphstk.lib : $(Dep_Linkgraphlibstk)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkgraphlibstk)

Linkgraph.lib : $(Dep_Linkgraphlib)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkgraphlib)

Linkbasicstk.lib : $(Dep_Linkbasiclibstk)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkbasiclibstk)

Linkbasic.lib : $(Dep_Linkbasiclib)
   $(LIB32) $(LIB_FLAGS) /out:$@ $(Dep_Linkbasiclib)

Dep_Linkexe = Link.res $(WRK)/userinit.obj \
	      Linklaystk.lib Linklay.lib \
	      Linkalgstk.lib Linkalg.lib \
	      Linkgenstk.lib Linkgen.lib \
              Linkuserobjstk.lib Linkuserobj.lib \
              Linkgraphstk.lib Linkbasicstk.lib \
              Linkgraph.lib Linkbasic.lib \
	      $(STKLIBS)

Link.exe : $(Dep_Linkexe)
  $(LINK) /out:$@ $(LINK_FLAGS) $(Dep_Linkexe) $(SYSLIBS)


{..\src\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\basic\}.cpp{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<

{..\src\basic\linkTemplates\}.cpp{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<

{..\src\basic\STkTemplates\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\basic\autogenSTkMethods\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\basic\manualSTkMethods\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\graph\}.c{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<

{..\src\graph\}.cpp{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<

{..\src\graph\linkTemplates\}.cpp{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<

{..\src\graph\STkTemplates\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\graph\autogenSTkMethods\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\graph\manualSTkMethods\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\userobj\}.cpp{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<

{..\src\userobj\linkTemplates\}.cpp{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<

{..\src\userobj\STkTemplates\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\userobj\autogenSTkMethods\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\userobj\manualSTkMethods\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\layout\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\layout\manualSTkWrappers}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\generator\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\generator\manualSTkWrappers}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\algorithm\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\algorithm\manualSTkWrappers}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\wrappers\}.cpp{$(WRK)}.obj:
	$(CC) $(CFLAGS) -Fo$@ $<

{..\src\stkWrapper\}.cpp{$(WRK)}.obj:
        $(CC) $(CFLAGS) -Fo$@ $<
