// Copyright (C) 1996 DIMACS Center, Rutgers, The State University of New Jersey
// Author(s): Jonathan Berry

// This software is copyrighted by the DIMACS Center at Rutgers, The State
// University of New Jersey.  IT IS PROVIDED AS IS, AND THE AUTHORS, DIMACS, AND
// RUTGERS, THE STATE UNIVERSITY OF NEW JERSEY  DISCLAIM
// ALL LIABILITY FOR DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR CONSEQUENTIAL
// DAMAGES ARISING OUT OF THE USE OF THIS SOFTWARE, ITS DOCUMENTATION, OR ANY
// DERIVATIVES THEREOF, EVEN IF THE AUTHORS HAVE BEEN ADVISED OF THE
// POSSIBILITY OF SUCH DAMAGE.

// THE AUTHORS AND DISTRIBUTORS SPECIFICALLY DISCLAIM ANY WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  THIS SOFTWARE
// IS PROVIDED ON AN "AS IS" BASIS, AND THE AUTHORS AND DISTRIBUTORS HAVE
// NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS, OR
// MODIFICATIONS.

// The authors hereby grant permission to use, copy, modify, distribute,
// and license this software and its documentation for any purpose, provided
// that existing copyright notices are retained in all copies and that this
// notice is included verbatim in any distributions. No written agreement,
// license, or royalty fee is required for any of the authorized uses.
// Modifications to this software may be copyrighted by their authors
// and need not follow the licensing terms described here, provided that
// the new terms are clearly indicated on the first page of each file where
// they apply.

// Last File Update: 31-Jul-1996
// 

///////////////////////////////////////////////////////////////////////////
// LINK: Generic Graph Tool and Class Library
//
//      Function name: Collection methods
//
//      Synopsis: Contains the implementations of the Collection and 
//		  Iterator methods.  See the document on Collections
//		  in the doc directory for a thorough discussion.
//		  A significant amount of the set and sequence code
//		  is actually located in the header file Collection.h
//		  This is because set and sequence are largely just
//		  "empty shells" that parameterized by implementation 
//		  type and mainly call the methods of the implementation.
//		  This file contains mainly the code for copy constructors,
//		  assignment operators, and iterator methods.
//
//      Description: Collections may be thought of as abstract objects
//		     that may be any kind of set or sequence.  The 
//		     purpose of the grouping is to allow various types
//		     of sets and sequences to interact with each other.
//		     "Collection" is an abstract base class, meaning that
//		     no Collection objects may be declared.  Rather, a 
//		     Collection pointer may point to and access the methods
//		     of any set or sequence.  This feature simplifies the
//		     implementation of graph primitive routines by allowing
//		     all types of edges to be thought of simply as 
//		     Collections.  
//
//      Creation: 1993 July 30, Jonathan W. Berry, berryj@cs.rpi.edu
//
//      Routines used: None.
//
//      Related files: Collection.h, List.h (since List is the default
//                     implementation.  If the default changes, the included
//		       file must change.)
//
//      Test suite: 
//
//      User documentation: see doc
//
//      Testing History:
//
//      Code Review:
//
//      Bugs and Deficiencies:
//
//////////////////////////////////////////////////////////////////////////////
#ifndef Sequence_CC
#define Sequence_CC

#include<LINK/basic/Array.h>

template <class Item>
Sequence<Item>&
Sequence<Item>::operator=(const Sequence<Item>& seq)
{
    if (&seq == this)
	return *this;
    ((Container<Item>*)store)->decrRefCount(); 
    if (((Container<Item>*)store)->getRefCount() == 0)
	delete store;
    //if (--store->ref_count == 0)
    //	delete store;
    store = seq.store;
    //store->ref_count++;
    ((Container<Item>*)store)->incrRefCount();
    return *this;
}


template <class Item>
Sequence<Item>&
Sequence<Item>::operator=(const Collection<Item>& col)
{
    Iterator<Item> get_next(&col);
    Item item; 
    newStore();
    while (get_next(item))
	append(item);
    return *this;
}

#endif
